@@ -69,12 +69,16 @@ def conlog(*args):
     for tx in args:
         text += f"{tx} "
     trc = traceback.extract_stack()[-2]
-    str = f'\033[1;33m {date} \033[0m | \033[4;31m{trc.filename.split("/")[-1]}\033[0m  | \033[1;32m {trc.name} : {trc.lineno}\033[0m  |  {text}'
+    filename = trc.filename
+    str = lambda: filename.split("\\")[-1] if "\\" in filename else filename.split('/')[-1]
+    str = f'\033[1;32m{date} \033[0m | \033[4;31m{str()}\033[0m  | \033[1;33m {trc.name} : {trc.lineno}\033[0m  |  {text}'
     print(str)
     return str
 
+
 def tt():
     conlog(90)
 
+
 if __name__ == '__main__':
   tt()
